# Security Policy

## Reporting Security Issues

The FIREWHEEL team and community take security bugs in FIREWHEEL seriously.
We appreciate your efforts to responsibly disclose your findings, and will make every effort to acknowledge your contributions.

To report a security issue, please email our development team at `firewheel AT sandia DOT gov`.

The FIREWHEEL team will send a response indicating the next steps in handling your report.
After the initial reply to your report, the development team will keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules and model components to the person or team maintaining the module or model component.

## Learning More About Security

To learn more about existing security issues, please see [FIREWHEEL Security](firewheel_security).
